import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * CRUD operations for New Relic Tags via the NerdGraph API
 *
 * @schema CfnTaggingProps
 */
export interface CfnTaggingProps {
    /**
     * @schema CfnTaggingProps#Endpoint
     */
    readonly endpoint?: string;
    /**
     * @schema CfnTaggingProps#APIKey
     */
    readonly apiKey: string;
    /**
     * @schema CfnTaggingProps#Guid
     */
    readonly guid?: string;
    /**
     * @schema CfnTaggingProps#EntityGuid
     */
    readonly entityGuid: string;
    /**
     * @schema CfnTaggingProps#ListQueryFilter
     */
    readonly listQueryFilter?: string;
    /**
     * @schema CfnTaggingProps#Variables
     */
    readonly variables?: any;
    /**
     * @schema CfnTaggingProps#Tags
     */
    readonly tags: TagObject[];
    /**
     * @schema CfnTaggingProps#Semantics
     */
    readonly semantics?: string;
}
/**
 * Converts an object of type 'CfnTaggingProps' to JSON representation.
 */
export declare function toJson_CfnTaggingProps(obj: CfnTaggingProps | undefined): Record<string, any> | undefined;
/**
 * @schema TagObject
 */
export interface TagObject {
    /**
     * @schema TagObject#Key
     */
    readonly key: string;
    /**
     * @schema TagObject#Values
     */
    readonly values: string[];
}
/**
 * Converts an object of type 'TagObject' to JSON representation.
 */
export declare function toJson_TagObject(obj: TagObject | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `newrelic::cloudformation::tagging`
 *
 * @cloudformationResource newrelic::cloudformation::tagging
 * @stability external
 * @link https://github.com/newrelic-experimental/newrelic-cloudformation-resource-providers-tagging.git
 */
export declare class CfnTagging extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "newrelic::cloudformation::tagging";
    /**
     * Resource props.
     */
    readonly props: CfnTaggingProps;
    /**
     * Create a new `newrelic::cloudformation::tagging`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnTaggingProps);
}
